package io.hmit.modules.serviceOrder.controller;

import io.hmit.common.constant.Constant;
import io.hmit.common.enums.EventEnum;
import io.hmit.common.page.PageData;
import io.hmit.common.utils.Result;
import io.hmit.modules.serviceOrder.dto.PensionEventDTO;
import io.hmit.modules.serviceOrder.service.PensionEventService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import springfox.documentation.annotations.ApiIgnore;

import java.util.HashMap;
import java.util.List;
import java.util.Map;


/**
 * 活动表
 *
 * @author Shen Yuanfeng syf0412@vip.qq.com
 * @since 1.0.0 2021-05-12
 */
@RestController
@RequestMapping("serviceOrder/pensionevent")
@Api(tags="活动表")
public class PensionEventController {
    @Autowired
    private PensionEventService pensionEventService;

    @GetMapping("page")
    @ApiOperation("分页")
    @ApiImplicitParams({
        @ApiImplicitParam(name = Constant.PAGE, value = "当前页码，从1开始", paramType = "query", required = true, dataType="int") ,
        @ApiImplicitParam(name = Constant.LIMIT, value = "每页显示记录数", paramType = "query",required = true, dataType="int") ,
        @ApiImplicitParam(name = Constant.ORDER_FIELD, value = "排序字段", paramType = "query", dataType="String") ,
        @ApiImplicitParam(name = Constant.ORDER, value = "排序方式，可选值(asc、desc)", paramType = "query", dataType="String")
    })
    public Result<PageData<PensionEventDTO>> page(@ApiIgnore @RequestParam Map<String, Object> params){
        PageData<PensionEventDTO> page = pensionEventService.page(params);

        return new Result<PageData<PensionEventDTO>>().ok(page);
    }

    @GetMapping("userPage")
    @ApiOperation(value = "展示分页", notes = "返回值不包括未发布和隐藏内容")
    @ApiImplicitParams({
            @ApiImplicitParam(name = Constant.PAGE, value = "当前页码，从1开始", paramType = "query", required = true, dataType="int") ,
            @ApiImplicitParam(name = Constant.LIMIT, value = "每页显示记录数", paramType = "query",required = true, dataType="int") ,
            @ApiImplicitParam(name = Constant.ORDER_FIELD, value = "排序字段", paramType = "query", dataType="String") ,
            @ApiImplicitParam(name = Constant.ORDER, value = "排序方式，可选值(asc、desc)", paramType = "query", dataType="String")
    })
    public Result<PageData<PensionEventDTO>> userPage(@ApiIgnore @RequestParam Map<String, Object> params){
        PageData<PensionEventDTO> page = pensionEventService.getUserPage(params);
        return new Result<PageData<PensionEventDTO>>().ok(page);
    }

    @GetMapping("{id}")
    @ApiOperation("信息")
    public Result<PensionEventDTO> get(@PathVariable("id") Long id){
        PensionEventDTO data = pensionEventService.get(id);

        return new Result<PensionEventDTO>().ok(data);
    }

    @GetMapping("getAllStatus")
    @ApiOperation("获取状态枚举")
    public Result getAllStatus() {
        Map<String, String> map = new HashMap<>();
        EventEnum[] status = EventEnum.values();
        for (EventEnum eventEnum : status) {
            map.put(eventEnum.getCode().toString(), eventEnum.getMsg());
        }
        return new Result().ok(map);
    }

//    @PostMapping
//    @ApiOperation("保存")
//    public Result save(@RequestBody PensionEventDTO dto){
//        //校验数据
//        ValidatorUtils.validateEntity(dto, AddGroup.class, DefaultGroup.class);
//
//        pensionEventService.save(dto);
//
//        return new Result();
//    }

//    @PutMapping
//    @ApiOperation("修改")
//    public Result update(@RequestBody PensionEventDTO dto){
//        //校验数据
//        ValidatorUtils.validateEntity(dto, UpdateGroup.class, DefaultGroup.class);
//
//        pensionEventService.update(dto);
//
//        return new Result();
//    }

//    @DeleteMapping
//    @ApiOperation("删除")
//    public Result delete(@RequestBody Long[] ids){
//        //校验数据
//        AssertUtils.isArrayEmpty(ids, "id");
//
//        pensionEventService.delete(ids);
//
//        return new Result();
//    }

}